Quantum Espresso tools for XML Schema based Documents
=====================================================

Tools for converting XML data produced by the Quantum ESPRESSO suite of codes 
(ESPRESSO: opEn-Source Package for Research in Electronic Structure, Simulation, 
and Optimization).

Requirements
------------

* Python_ 2.7, 3.4-3.7
* xmlschema_ (Python library for processing XML Schema based documents)

.. _Python: http://www.python.org/
.. _xmlschema: https://github.com/brunato/xmlschema


